@@ -61,11 +61,11 @@ EOT
         $apcu = $input->getOption('apcu') || $config->get('apcu-autoloader');
 
         if ($authoritative) {
-            $this->getIO()->writeError('<info>Generating optimized autoload files (authoritative)</info>');
+            $this->getIO()->writeError('<info>Generating optimized autoload files (authoritative)</info>', false);
         } elseif ($optimize) {
-            $this->getIO()->writeError('<info>Generating optimized autoload files</info>');
+            $this->getIO()->writeError('<info>Generating optimized autoload files</info>', false);
         } else {
-            $this->getIO()->writeError('<info>Generating autoload files</info>');
+            $this->getIO()->writeError('<info>Generating autoload files</info>', false);
         }
 
         $generator = $composer->getAutoloadGenerator();
@@ -73,6 +73,14 @@ EOT
         $generator->setClassMapAuthoritative($authoritative);
         $generator->setApcu($apcu);
         $generator->setRunScripts(!$input->getOption('no-scripts'));
-        $generator->dump($config, $localRepo, $package, $installationManager, 'composer', $optimize);
+        $numberOfClasses = $generator->dump($config, $localRepo, $package, $installationManager, 'composer', $optimize);
+
+        if ($authoritative) {
+            $this->getIO()->overwriteError('<info>Generated optimized autoload files (authoritative) containing '. $numberOfClasses .' classes</info>');
+        } elseif ($optimize) {
+            $this->getIO()->overwriteError('<info>Generated optimized autoload files containing '. $numberOfClasses .' classes</info>');
+        } else {
+            $this->getIO()->overwriteError('<info>Generated autoload files containing '. $numberOfClasses .' classes</info>');
+        }
     }
 }
