@@ -42,7 +42,8 @@ class HomeCommand extends BaseCommand
                 new InputOption('homepage', 'H', InputOption::VALUE_NONE, 'Open the homepage instead of the repository URL.'),
                 new InputOption('show', 's', InputOption::VALUE_NONE, 'Only show the homepage or repository URL.'),
             ))
-            ->setHelp(<<<EOT
+            ->setHelp(
+                <<<EOT
 The home command opens or shows a package's repository URL or
 homepage in your default browser.
 
