@@ -31,7 +31,8 @@ class ProhibitsCommand extends BaseDependencyCommand
             ->setName('prohibits')
             ->setAliases(array('why-not'))
             ->setDescription('Shows which packages prevent the given package from being installed.')
-            ->setHelp(<<<EOT
+            ->setHelp(
+                <<<EOT
 Displays detailed information about why a package cannot be installed.
 
 <info>php composer.phar prohibits composer/composer</info>
