@@ -336,6 +336,38 @@ class ValidatingArrayLoader implements LoaderInterface
         return $this->errors;
     }
 
+    public static function hasPackageNamingError($name, $isLink = false)
+    {
+        if (preg_match(PlatformRepository::PLATFORM_PACKAGE_REGEX, $name)) {
+            return;
+        }
+
+        if (!preg_match('{^[a-z0-9]([_.-]?[a-z0-9]+)*/[a-z0-9]([_.-]?[a-z0-9]+)*$}iD', $name)) {
+            return $name.' is invalid, it should have a vendor name, a forward slash, and a package name. The vendor and package name can be words separated by -, . or _. The complete name should match "[a-z0-9]([_.-]?[a-z0-9]+)*/[a-z0-9]([_.-]?[a-z0-9]+)*".';
+        }
+
+        $reservedNames = array('nul', 'con', 'prn', 'aux', 'com1', 'com2', 'com3', 'com4', 'com5', 'com6', 'com7', 'com8', 'com9', 'lpt1', 'lpt2', 'lpt3', 'lpt4', 'lpt5', 'lpt6', 'lpt7', 'lpt8', 'lpt9');
+        $bits = explode('/', strtolower($name));
+        if (in_array($bits[0], $reservedNames, true) || in_array($bits[1], $reservedNames, true)) {
+            return $name.' is reserved, package and vendor names can not match any of: '.implode(', ', $reservedNames).'.';
+        }
+
+        if (preg_match('{\.json$}', $name)) {
+            return $name.' is invalid, package names can not end in .json, consider renaming it or perhaps using a -json suffix instead.';
+        }
+
+        if (preg_match('{[A-Z]}', $name)) {
+            if ($isLink) {
+                return $name.' is invalid, it should not contain uppercase characters. Please use '.strtolower($name).' instead.';
+            }
+
+            $suggestName = preg_replace('{(?:([a-z])([A-Z])|([A-Z])([A-Z][a-z]))}', '\\1\\3-\\2\\4', $name);
+            $suggestName = strtolower($suggestName);
+
+            return $name.' is invalid, it should not contain uppercase characters. We suggest using '.$suggestName.' instead.';
+        }
+    }
+
     private function validateRegex($property, $regex, $mandatory = false)
     {
         if (!$this->validateString($property, $mandatory)) {
